Struct Error
pub struct Error(Box<ErrorRepr>);Expand description
The error type which is used when loading an asset.
Tuple Fields
0: Box<ErrorRepr>Implementations
impl Error
impl Error
pub fn id(&self) -> &SharedString
pub fn id(&self) -> &SharedString
The id of the asset that was being loaded when the error happened.
pub fn into_inner(self) -> Box<dyn Error + Send + Sync>
pub fn into_inner(self) -> Box<dyn Error + Send + Sync>
Consumes the Error, returning its inner error.